==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Gnss_/Sv_/Sbas_/Msas_/Nmessage_/Nav_/Time_/Conversion_/Utc_/Aone_/Unscaled.py <==
from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup
from ..............Internal import Conversions
from .............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Unscaled:
	"""Unscaled commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("unscaled", core, parent)

	def set(self, a_1: float, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:GNSS:SV:SBAS<ST>:MSAS:NMESsage:NAV:TIME:CONVersion:UTC<CH>:AONE:UNSCaled \n
		Sets the parameter A1. \n
			:param a_1: integer Range: -4096 to 4095
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sbas')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Utc')"""
		param = Conversions.decimal_value_to_str(a_1)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS{stream_cmd_val}:MSAS:NMESsage:NAV:TIME:CONVersion:UTC{channel_cmd_val}:AONE:UNSCaled {param}')

	def get(self, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> float:
		"""[SOURce<HW>]:BB:GNSS:SV:SBAS<ST>:MSAS:NMESsage:NAV:TIME:CONVersion:UTC<CH>:AONE:UNSCaled \n
		Sets the parameter A1. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sbas')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Utc')
			:return: a_1: integer Range: -4096 to 4095"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS{stream_cmd_val}:MSAS:NMESsage:NAV:TIME:CONVersion:UTC{channel_cmd_val}:AONE:UNSCaled?')
		return Conversions.str_to_float(response)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Gnss_/Sv_/Sbas_/Msas_/Nmessage_/Nav_/Time_/Conversion_/Utc_/Aone_/Unscaled.py <==
from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup
from ..............Internal import Conversions
from .............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Unscaled:
	"""Unscaled commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("unscaled", core, parent)

	def set(self, a_1: float, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS<ST>:MSAS:NMESsage:NAV:TIME:CONVersion:UTC<CH>:AONE:UNSCaled \n
		Snippet: driver.source.bb.gnss.sv.sbas.msas.nmessage.nav.time.conversion.utc.aone.unscaled.set(a_1 = 1.0, stream = repcap.Stream.Default, channel = repcap.Channel.Default) \n
		Sets the parameter A1. \n
			:param a_1: integer Range: -4096 to 4095
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sbas')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Utc')"""
		param = Conversions.decimal_value_to_str(a_1)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS{stream_cmd_val}:MSAS:NMESsage:NAV:TIME:CONVersion:UTC{channel_cmd_val}:AONE:UNSCaled {param}')

	def get(self, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS<ST>:MSAS:NMESsage:NAV:TIME:CONVersion:UTC<CH>:AONE:UNSCaled \n
		Snippet: value: float = driver.source.bb.gnss.sv.sbas.msas.nmessage.nav.time.conversion.utc.aone.unscaled.get(stream = repcap.Stream.Default, channel = repcap.Channel.Default) \n
		Sets the parameter A1. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sbas')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Utc')
			:return: a_1: integer Range: -4096 to 4095"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS{stream_cmd_val}:MSAS:NMESsage:NAV:TIME:CONVersion:UTC{channel_cmd_val}:AONE:UNSCaled?')
		return Conversions.str_to_float(response)
